@@ -19,16 +19,18 @@ class TestSystemSpeech(object):
     def test_synthesize_speech(self):
         client = texttospeech_v1.TextToSpeechClient()
 
-        synthesis_input = texttospeech_v1.types.SynthesisInput(text="Hello, World!")
-        voice = texttospeech_v1.types.VoiceSelectionParams(
-            language_code="en-US",
-            ssml_gender=texttospeech_v1.enums.SsmlVoiceGender.NEUTRAL,
+        synthesis_input = texttospeech_v1.SynthesisInput(text="Hello, World!")
+        voice = texttospeech_v1.VoiceSelectionParams(
+            language_code="en-US", ssml_gender=texttospeech_v1.SsmlVoiceGender.NEUTRAL
         )
-        audio_config = texttospeech_v1.types.AudioConfig(
-            audio_encoding=texttospeech_v1.enums.AudioEncoding.MP3
+        audio_config = texttospeech_v1.AudioConfig(
+            audio_encoding=texttospeech_v1.AudioEncoding.MP3
+        )
+
+        response = client.synthesize_speech(
+            input=synthesis_input, voice=voice, audio_config=audio_config
         )
 
-        response = client.synthesize_speech(synthesis_input, voice, audio_config)
         assert response.audio_content is not None
 
     def test_list_voices(self):
