@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,9 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import os
 import mock
+import packaging.version
 
 import grpc
 from grpc.experimental import aio
@@ -24,19 +23,49 @@ import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
 
-from google import auth
+
 from google.api_core import client_options
-from google.api_core import exceptions
+from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
-from google.auth import credentials
+from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.cloud.texttospeech_v1.services.text_to_speech import TextToSpeechAsyncClient
 from google.cloud.texttospeech_v1.services.text_to_speech import TextToSpeechClient
 from google.cloud.texttospeech_v1.services.text_to_speech import transports
+from google.cloud.texttospeech_v1.services.text_to_speech.transports.base import (
+    _API_CORE_VERSION,
+)
+from google.cloud.texttospeech_v1.services.text_to_speech.transports.base import (
+    _GOOGLE_AUTH_VERSION,
+)
 from google.cloud.texttospeech_v1.types import cloud_tts
 from google.oauth2 import service_account
+import google.auth
+
+
+# TODO(busunkim): Once google-api-core >= 1.26.0 is required:
+# - Delete all the api-core and auth "less than" test cases
+# - Delete these pytest markers (Make the "greater than or equal to" tests the default).
+requires_google_auth_lt_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) >= packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth < 1.25.0",
+)
+requires_google_auth_gte_1_25_0 = pytest.mark.skipif(
+    packaging.version.parse(_GOOGLE_AUTH_VERSION) < packaging.version.parse("1.25.0"),
+    reason="This test requires google-auth >= 1.25.0",
+)
+
+requires_api_core_lt_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) >= packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core < 1.26.0",
+)
+
+requires_api_core_gte_1_26_0 = pytest.mark.skipif(
+    packaging.version.parse(_API_CORE_VERSION) < packaging.version.parse("1.26.0"),
+    reason="This test requires google-api-core >= 1.26.0",
+)
 
 
 def client_cert_source_callback():
@@ -82,7 +111,7 @@ def test__get_default_mtls_endpoint():
 
 @pytest.mark.parametrize("client_class", [TextToSpeechClient, TextToSpeechAsyncClient,])
 def test_text_to_speech_client_from_service_account_info(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
@@ -97,7 +126,7 @@ def test_text_to_speech_client_from_service_account_info(client_class):
 
 @pytest.mark.parametrize("client_class", [TextToSpeechClient, TextToSpeechAsyncClient,])
 def test_text_to_speech_client_from_service_account_file(client_class):
-    creds = credentials.AnonymousCredentials()
+    creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
@@ -148,7 +177,7 @@ def test_text_to_speech_client_client_options(
 ):
     # Check that if channel is provided we won't create a new one.
     with mock.patch.object(TextToSpeechClient, "get_transport_class") as gtc:
-        transport = transport_class(credentials=credentials.AnonymousCredentials())
+        transport = transport_class(credentials=ga_credentials.AnonymousCredentials())
         client = client_class(transport=transport)
         gtc.assert_not_called()
 
@@ -430,7 +459,7 @@ def test_text_to_speech_client_client_options_from_dict():
 
 def test_list_voices(transport: str = "grpc", request_type=cloud_tts.ListVoicesRequest):
     client = TextToSpeechClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -441,17 +470,14 @@ def test_list_voices(transport: str = "grpc", request_type=cloud_tts.ListVoicesR
     with mock.patch.object(type(client.transport.list_voices), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = cloud_tts.ListVoicesResponse()
-
         response = client.list_voices(request)
 
         # Establish that the underlying gRPC stub method was called.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == cloud_tts.ListVoicesRequest()
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, cloud_tts.ListVoicesResponse)
 
 
@@ -463,7 +489,7 @@ def test_list_voices_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = TextToSpeechClient(
-        credentials=credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -471,7 +497,6 @@ def test_list_voices_empty_call():
         client.list_voices()
         call.assert_called()
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == cloud_tts.ListVoicesRequest()
 
 
@@ -480,7 +505,7 @@ async def test_list_voices_async(
     transport: str = "grpc_asyncio", request_type=cloud_tts.ListVoicesRequest
 ):
     client = TextToSpeechAsyncClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -493,13 +518,11 @@ async def test_list_voices_async(
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             cloud_tts.ListVoicesResponse()
         )
-
         response = await client.list_voices(request)
 
         # Establish that the underlying gRPC stub method was called.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == cloud_tts.ListVoicesRequest()
 
     # Establish that the response is the type that we expect.
@@ -512,13 +535,12 @@ async def test_list_voices_async_from_dict():
 
 
 def test_list_voices_flattened():
-    client = TextToSpeechClient(credentials=credentials.AnonymousCredentials(),)
+    client = TextToSpeechClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.list_voices), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = cloud_tts.ListVoicesResponse()
-
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         client.list_voices(language_code="language_code_value",)
@@ -527,12 +549,11 @@ def test_list_voices_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-
         assert args[0].language_code == "language_code_value"
 
 
 def test_list_voices_flattened_error():
-    client = TextToSpeechClient(credentials=credentials.AnonymousCredentials(),)
+    client = TextToSpeechClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -544,7 +565,7 @@ def test_list_voices_flattened_error():
 
 @pytest.mark.asyncio
 async def test_list_voices_flattened_async():
-    client = TextToSpeechAsyncClient(credentials=credentials.AnonymousCredentials(),)
+    client = TextToSpeechAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.list_voices), "__call__") as call:
@@ -562,13 +583,12 @@ async def test_list_voices_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-
         assert args[0].language_code == "language_code_value"
 
 
 @pytest.mark.asyncio
 async def test_list_voices_flattened_error_async():
-    client = TextToSpeechAsyncClient(credentials=credentials.AnonymousCredentials(),)
+    client = TextToSpeechAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -582,7 +602,7 @@ def test_synthesize_speech(
     transport: str = "grpc", request_type=cloud_tts.SynthesizeSpeechRequest
 ):
     client = TextToSpeechClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -597,19 +617,15 @@ def test_synthesize_speech(
         call.return_value = cloud_tts.SynthesizeSpeechResponse(
             audio_content=b"audio_content_blob",
         )
-
         response = client.synthesize_speech(request)
 
         # Establish that the underlying gRPC stub method was called.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == cloud_tts.SynthesizeSpeechRequest()
 
     # Establish that the response is the type that we expect.
-
     assert isinstance(response, cloud_tts.SynthesizeSpeechResponse)
-
     assert response.audio_content == b"audio_content_blob"
 
 
@@ -621,7 +637,7 @@ def test_synthesize_speech_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = TextToSpeechClient(
-        credentials=credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -631,7 +647,6 @@ def test_synthesize_speech_empty_call():
         client.synthesize_speech()
         call.assert_called()
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == cloud_tts.SynthesizeSpeechRequest()
 
 
@@ -640,7 +655,7 @@ async def test_synthesize_speech_async(
     transport: str = "grpc_asyncio", request_type=cloud_tts.SynthesizeSpeechRequest
 ):
     client = TextToSpeechAsyncClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -655,18 +670,15 @@ async def test_synthesize_speech_async(
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             cloud_tts.SynthesizeSpeechResponse(audio_content=b"audio_content_blob",)
         )
-
         response = await client.synthesize_speech(request)
 
         # Establish that the underlying gRPC stub method was called.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-
         assert args[0] == cloud_tts.SynthesizeSpeechRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, cloud_tts.SynthesizeSpeechResponse)
-
     assert response.audio_content == b"audio_content_blob"
 
 
@@ -676,7 +688,7 @@ async def test_synthesize_speech_async_from_dict():
 
 
 def test_synthesize_speech_flattened():
-    client = TextToSpeechClient(credentials=credentials.AnonymousCredentials(),)
+    client = TextToSpeechClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -684,7 +696,6 @@ def test_synthesize_speech_flattened():
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = cloud_tts.SynthesizeSpeechResponse()
-
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         client.synthesize_speech(
@@ -699,20 +710,17 @@ def test_synthesize_speech_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-
         assert args[0].input == cloud_tts.SynthesisInput(text="text_value")
-
         assert args[0].voice == cloud_tts.VoiceSelectionParams(
             language_code="language_code_value"
         )
-
         assert args[0].audio_config == cloud_tts.AudioConfig(
             audio_encoding=cloud_tts.AudioEncoding.LINEAR16
         )
 
 
 def test_synthesize_speech_flattened_error():
-    client = TextToSpeechClient(credentials=credentials.AnonymousCredentials(),)
+    client = TextToSpeechClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -729,7 +737,7 @@ def test_synthesize_speech_flattened_error():
 
 @pytest.mark.asyncio
 async def test_synthesize_speech_flattened_async():
-    client = TextToSpeechAsyncClient(credentials=credentials.AnonymousCredentials(),)
+    client = TextToSpeechAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -755,13 +763,10 @@ async def test_synthesize_speech_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-
         assert args[0].input == cloud_tts.SynthesisInput(text="text_value")
-
         assert args[0].voice == cloud_tts.VoiceSelectionParams(
             language_code="language_code_value"
         )
-
         assert args[0].audio_config == cloud_tts.AudioConfig(
             audio_encoding=cloud_tts.AudioEncoding.LINEAR16
         )
@@ -769,7 +774,7 @@ async def test_synthesize_speech_flattened_async():
 
 @pytest.mark.asyncio
 async def test_synthesize_speech_flattened_error_async():
-    client = TextToSpeechAsyncClient(credentials=credentials.AnonymousCredentials(),)
+    client = TextToSpeechAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -787,16 +792,16 @@ async def test_synthesize_speech_flattened_error_async():
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.TextToSpeechGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = TextToSpeechClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
     transport = transports.TextToSpeechGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = TextToSpeechClient(
@@ -806,7 +811,7 @@ def test_credentials_transport_error():
 
     # It is an error to provide scopes and a transport instance.
     transport = transports.TextToSpeechGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = TextToSpeechClient(
@@ -817,7 +822,7 @@ def test_credentials_transport_error():
 def test_transport_instance():
     # A client may be instantiated with a custom transport instance.
     transport = transports.TextToSpeechGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     client = TextToSpeechClient(transport=transport)
     assert client.transport is transport
@@ -826,13 +831,13 @@ def test_transport_instance():
 def test_transport_get_channel():
     # A client may be instantiated with a custom transport instance.
     transport = transports.TextToSpeechGrpcTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     channel = transport.grpc_channel
     assert channel
 
     transport = transports.TextToSpeechGrpcAsyncIOTransport(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
     )
     channel = transport.grpc_channel
     assert channel
@@ -847,23 +852,23 @@ def test_transport_get_channel():
 )
 def test_transport_adc(transport_class):
     # Test default credentials are used if not provided.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default") as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport_class()
         adc.assert_called_once()
 
 
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = TextToSpeechClient(credentials=credentials.AnonymousCredentials(),)
+    client = TextToSpeechClient(credentials=ga_credentials.AnonymousCredentials(),)
     assert isinstance(client.transport, transports.TextToSpeechGrpcTransport,)
 
 
 def test_text_to_speech_base_transport_error():
     # Passing both a credentials object and credentials_file should raise an error
-    with pytest.raises(exceptions.DuplicateCredentialArgs):
+    with pytest.raises(core_exceptions.DuplicateCredentialArgs):
         transport = transports.TextToSpeechTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
             credentials_file="credentials.json",
         )
 
@@ -875,7 +880,7 @@ def test_text_to_speech_base_transport():
     ) as Transport:
         Transport.return_value = None
         transport = transports.TextToSpeechTransport(
-            credentials=credentials.AnonymousCredentials(),
+            credentials=ga_credentials.AnonymousCredentials(),
         )
 
     # Every method on the transport should just blindly
@@ -889,15 +894,37 @@ def test_text_to_speech_base_transport():
             getattr(transport, method)(request=object())
 
 
+@requires_google_auth_gte_1_25_0
 def test_text_to_speech_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
     with mock.patch.object(
-        auth, "load_credentials_from_file"
+        google.auth, "load_credentials_from_file", autospec=True
     ) as load_creds, mock.patch(
         "google.cloud.texttospeech_v1.services.text_to_speech.transports.TextToSpeechTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        load_creds.return_value = (credentials.AnonymousCredentials(), None)
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport = transports.TextToSpeechTransport(
+            credentials_file="credentials.json", quota_project_id="octopus",
+        )
+        load_creds.assert_called_once_with(
+            "credentials.json",
+            scopes=None,
+            default_scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            quota_project_id="octopus",
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_text_to_speech_base_transport_with_credentials_file_old_google_auth():
+    # Instantiate the base transport with a credentials file
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch(
+        "google.cloud.texttospeech_v1.services.text_to_speech.transports.TextToSpeechTransport._prep_wrapped_messages"
+    ) as Transport:
+        Transport.return_value = None
+        load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.TextToSpeechTransport(
             credentials_file="credentials.json", quota_project_id="octopus",
         )
@@ -910,19 +937,33 @@ def test_text_to_speech_base_transport_with_credentials_file():
 
 def test_text_to_speech_base_transport_with_adc():
     # Test the default credentials are used if credentials and credentials_file are None.
-    with mock.patch.object(auth, "default") as adc, mock.patch(
+    with mock.patch.object(google.auth, "default", autospec=True) as adc, mock.patch(
         "google.cloud.texttospeech_v1.services.text_to_speech.transports.TextToSpeechTransport._prep_wrapped_messages"
     ) as Transport:
         Transport.return_value = None
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.TextToSpeechTransport()
         adc.assert_called_once()
 
 
+@requires_google_auth_gte_1_25_0
 def test_text_to_speech_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        TextToSpeechClient()
+        adc.assert_called_once_with(
+            scopes=None,
+            default_scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            quota_project_id=None,
+        )
+
+
+@requires_google_auth_lt_1_25_0
+def test_text_to_speech_auth_adc_old_google_auth():
+    # If no credentials are provided, we should use ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
         TextToSpeechClient()
         adc.assert_called_once_with(
             scopes=("https://www.googleapis.com/auth/cloud-platform",),
@@ -930,26 +971,162 @@ def test_text_to_speech_auth_adc():
         )
 
 
-def test_text_to_speech_transport_auth_adc():
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.TextToSpeechGrpcTransport,
+        transports.TextToSpeechGrpcAsyncIOTransport,
+    ],
+)
+@requires_google_auth_gte_1_25_0
+def test_text_to_speech_transport_auth_adc(transport_class):
     # If credentials and host are not provided, the transport class should use
     # ADC credentials.
-    with mock.patch.object(auth, "default") as adc:
-        adc.return_value = (credentials.AnonymousCredentials(), None)
-        transports.TextToSpeechGrpcTransport(
-            host="squid.clam.whelk", quota_project_id="octopus"
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport_class(quota_project_id="octopus", scopes=["1", "2"])
+        adc.assert_called_once_with(
+            scopes=["1", "2"],
+            default_scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            quota_project_id="octopus",
         )
+
+
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.TextToSpeechGrpcTransport,
+        transports.TextToSpeechGrpcAsyncIOTransport,
+    ],
+)
+@requires_google_auth_lt_1_25_0
+def test_text_to_speech_transport_auth_adc_old_google_auth(transport_class):
+    # If credentials and host are not provided, the transport class should use
+    # ADC credentials.
+    with mock.patch.object(google.auth, "default", autospec=True) as adc:
+        adc.return_value = (ga_credentials.AnonymousCredentials(), None)
+        transport_class(quota_project_id="octopus")
         adc.assert_called_once_with(
             scopes=("https://www.googleapis.com/auth/cloud-platform",),
             quota_project_id="octopus",
         )
 
 
+@pytest.mark.parametrize(
+    "transport_class,grpc_helpers",
+    [
+        (transports.TextToSpeechGrpcTransport, grpc_helpers),
+        (transports.TextToSpeechGrpcAsyncIOTransport, grpc_helpers_async),
+    ],
+)
+@requires_api_core_gte_1_26_0
+def test_text_to_speech_transport_create_channel(transport_class, grpc_helpers):
+    # If credentials and host are not provided, the transport class should use
+    # ADC credentials.
+    with mock.patch.object(
+        google.auth, "default", autospec=True
+    ) as adc, mock.patch.object(
+        grpc_helpers, "create_channel", autospec=True
+    ) as create_channel:
+        creds = ga_credentials.AnonymousCredentials()
+        adc.return_value = (creds, None)
+        transport_class(quota_project_id="octopus", scopes=["1", "2"])
+
+        create_channel.assert_called_with(
+            "texttospeech.googleapis.com:443",
+            credentials=creds,
+            credentials_file=None,
+            quota_project_id="octopus",
+            default_scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            scopes=["1", "2"],
+            default_host="texttospeech.googleapis.com",
+            ssl_credentials=None,
+            options=[
+                ("grpc.max_send_message_length", -1),
+                ("grpc.max_receive_message_length", -1),
+            ],
+        )
+
+
+@pytest.mark.parametrize(
+    "transport_class,grpc_helpers",
+    [
+        (transports.TextToSpeechGrpcTransport, grpc_helpers),
+        (transports.TextToSpeechGrpcAsyncIOTransport, grpc_helpers_async),
+    ],
+)
+@requires_api_core_lt_1_26_0
+def test_text_to_speech_transport_create_channel_old_api_core(
+    transport_class, grpc_helpers
+):
+    # If credentials and host are not provided, the transport class should use
+    # ADC credentials.
+    with mock.patch.object(
+        google.auth, "default", autospec=True
+    ) as adc, mock.patch.object(
+        grpc_helpers, "create_channel", autospec=True
+    ) as create_channel:
+        creds = ga_credentials.AnonymousCredentials()
+        adc.return_value = (creds, None)
+        transport_class(quota_project_id="octopus")
+
+        create_channel.assert_called_with(
+            "texttospeech.googleapis.com:443",
+            credentials=creds,
+            credentials_file=None,
+            quota_project_id="octopus",
+            scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            ssl_credentials=None,
+            options=[
+                ("grpc.max_send_message_length", -1),
+                ("grpc.max_receive_message_length", -1),
+            ],
+        )
+
+
+@pytest.mark.parametrize(
+    "transport_class,grpc_helpers",
+    [
+        (transports.TextToSpeechGrpcTransport, grpc_helpers),
+        (transports.TextToSpeechGrpcAsyncIOTransport, grpc_helpers_async),
+    ],
+)
+@requires_api_core_lt_1_26_0
+def test_text_to_speech_transport_create_channel_user_scopes(
+    transport_class, grpc_helpers
+):
+    # If credentials and host are not provided, the transport class should use
+    # ADC credentials.
+    with mock.patch.object(
+        google.auth, "default", autospec=True
+    ) as adc, mock.patch.object(
+        grpc_helpers, "create_channel", autospec=True
+    ) as create_channel:
+        creds = ga_credentials.AnonymousCredentials()
+        adc.return_value = (creds, None)
+
+        transport_class(quota_project_id="octopus", scopes=["1", "2"])
+
+        create_channel.assert_called_with(
+            "texttospeech.googleapis.com:443",
+            credentials=creds,
+            credentials_file=None,
+            quota_project_id="octopus",
+            scopes=["1", "2"],
+            ssl_credentials=None,
+            options=[
+                ("grpc.max_send_message_length", -1),
+                ("grpc.max_receive_message_length", -1),
+            ],
+        )
+
+
 @pytest.mark.parametrize(
     "transport_class",
     [transports.TextToSpeechGrpcTransport, transports.TextToSpeechGrpcAsyncIOTransport],
 )
 def test_text_to_speech_grpc_transport_client_cert_source_for_mtls(transport_class):
-    cred = credentials.AnonymousCredentials()
+    cred = ga_credentials.AnonymousCredentials()
 
     # Check ssl_channel_credentials is used if provided.
     with mock.patch.object(transport_class, "create_channel") as mock_create_channel:
@@ -988,7 +1165,7 @@ def test_text_to_speech_grpc_transport_client_cert_source_for_mtls(transport_cla
 
 def test_text_to_speech_host_no_port():
     client = TextToSpeechClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="texttospeech.googleapis.com"
         ),
@@ -998,7 +1175,7 @@ def test_text_to_speech_host_no_port():
 
 def test_text_to_speech_host_with_port():
     client = TextToSpeechClient(
-        credentials=credentials.AnonymousCredentials(),
+        credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="texttospeech.googleapis.com:8000"
         ),
@@ -1049,9 +1226,9 @@ def test_text_to_speech_transport_channel_mtls_with_client_cert_source(transport
             mock_grpc_channel = mock.Mock()
             grpc_create_channel.return_value = mock_grpc_channel
 
-            cred = credentials.AnonymousCredentials()
+            cred = ga_credentials.AnonymousCredentials()
             with pytest.warns(DeprecationWarning):
-                with mock.patch.object(auth, "default") as adc:
+                with mock.patch.object(google.auth, "default") as adc:
                     adc.return_value = (cred, None)
                     transport = transport_class(
                         host="squid.clam.whelk",
@@ -1124,7 +1301,6 @@ def test_text_to_speech_transport_channel_mtls_with_adc(transport_class):
 
 def test_common_billing_account_path():
     billing_account = "squid"
-
     expected = "billingAccounts/{billing_account}".format(
         billing_account=billing_account,
     )
@@ -1145,7 +1321,6 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-
     expected = "folders/{folder}".format(folder=folder,)
     actual = TextToSpeechClient.common_folder_path(folder)
     assert expected == actual
@@ -1164,7 +1339,6 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-
     expected = "organizations/{organization}".format(organization=organization,)
     actual = TextToSpeechClient.common_organization_path(organization)
     assert expected == actual
@@ -1183,7 +1357,6 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-
     expected = "projects/{project}".format(project=project,)
     actual = TextToSpeechClient.common_project_path(project)
     assert expected == actual
@@ -1203,7 +1376,6 @@ def test_parse_common_project_path():
 def test_common_location_path():
     project = "winkle"
     location = "nautilus"
-
     expected = "projects/{project}/locations/{location}".format(
         project=project, location=location,
     )
@@ -1230,7 +1402,7 @@ def test_client_withDEFAULT_CLIENT_INFO():
         transports.TextToSpeechTransport, "_prep_wrapped_messages"
     ) as prep:
         client = TextToSpeechClient(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1239,6 +1411,6 @@ def test_client_withDEFAULT_CLIENT_INFO():
     ) as prep:
         transport_class = TextToSpeechClient.get_transport_class()
         transport = transport_class(
-            credentials=credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
